# Test Coverage Report

Generated: Mon 2014-11-10 12:51 CET

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 362 | 320 | 42 | 100.0%
payslip.__init__ | 1 | 1 | 0 | 100.0%
payslip.forms | 135 | 127 | 8 | 100.0%
payslip.models | 67 | 50 | 17 | 100.0%
payslip.templatetags.payslip_tags | 9 | 6 | 3 | 100.0%
payslip.views | 150 | 136 | 14 | 100.0%

Excluded packages and modules
Error packages and modules